.. toctree::
   :hidden:
   :maxdepth: 3

   Changelog<CHANGELOG>
   Contributing<CONTRIBUTING>
   License<LICENSE>
   xstxt<xstxt>
   API<xsget>

.. include:: README.md
   :parser: myst_parser.sphinx_
